==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QStaticPlugin_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qplugin.h>
#include <QtCore/QVariant>
#include <QtCore/qjsonobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/JObjectWrapper>
#include <QtJambi/JavaAPI>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStaticPlugin(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStaticPlugin")
    QStaticPlugin *_ptr = reinterpret_cast<QStaticPlugin *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QStaticPlugin_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QStaticPlugin *__qt_this = new(__qtjambi_ptr) QStaticPlugin();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QStaticPlugin
void __qt_destruct_QStaticPlugin(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStaticPlugin")
    reinterpret_cast<QStaticPlugin*>(ptr)->~QStaticPlugin();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStaticPlugin::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStaticPlugin_initialize_1native__Lio_qt_core_QStaticPlugin_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStaticPlugin::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStaticPlugin_0, sizeof(QStaticPlugin), typeid(QStaticPlugin), false, &deleter_QStaticPlugin, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStaticPlugin::metaData()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStaticPlugin_metaData_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QStaticPlugin *__qt_this = QtJambiAPI::objectFromNativeId<QStaticPlugin>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStaticPlugin::metaData()const", __qt_this)
        QJsonObject __qt_return_value = __qt_this->metaData();
        QJsonValue iid = __qt_return_value.value("IID");
        if(iid.isString()){
            if(jclass iface = CoreAPI::getInterfaceByIID(__jni_env, iid.toString().toUtf8())){
                __qt_return_value.take("IID");
                __qt_return_value.insert("interface", QJsonValue::fromVariant(QVariant::fromValue<JObjectWrapper>(JObjectWrapper(__jni_env, iface))));
            }
        }
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStaticPlugin_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStaticPlugin *__qt_this = QtJambiAPI::objectFromNativeId<QStaticPlugin>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStaticPlugin(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStaticPlugin>("QStaticPlugin", "io/qt/core/QStaticPlugin");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStaticPlugin, {
        ConstructorInfo(&__qt_construct_QStaticPlugin_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStaticPlugin);
    registerMetaType<QStaticPlugin>("QStaticPlugin");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QStaticPlugin_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qplugin.h>
#include <QtCore/QVariant>
#include <QtCore/qjsonobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/JObjectWrapper>
#include <QtJambi/JavaAPI>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStaticPlugin(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStaticPlugin")
    QStaticPlugin *_ptr = reinterpret_cast<QStaticPlugin *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStaticPlugin()
void __qt_construct_QStaticPlugin(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStaticPlugin()")
    Q_UNUSED(__java_arguments)
    QStaticPlugin *__qt_this = new(__qtjambi_ptr) QStaticPlugin();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QStaticPlugin::QStaticPlugin()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStaticPlugin_initialize_1native__Lio_qt_core_QStaticPlugin_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStaticPlugin::QStaticPlugin()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStaticPlugin, sizeof(QStaticPlugin), typeid(QStaticPlugin), false, &deleter_QStaticPlugin, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStaticPlugin(QStaticPlugin)
void __qt_construct_QStaticPlugin_cref_QStaticPlugin(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStaticPlugin(QStaticPlugin)")
    jobject other0 = __java_arguments[0].l;
    const QStaticPlugin& __qt_other0 = qtjambi_cast<const QStaticPlugin& >(__jni_env, other0);
    QStaticPlugin *__qt_this = new(__qtjambi_ptr) QStaticPlugin(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStaticPlugin::QStaticPlugin(QStaticPlugin)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStaticPlugin_initialize_1native__Lio_qt_core_QStaticPlugin_2Lio_qt_core_QStaticPlugin_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStaticPlugin::QStaticPlugin(QStaticPlugin)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStaticPlugin_cref_QStaticPlugin, sizeof(QStaticPlugin), typeid(QStaticPlugin), false, &deleter_QStaticPlugin, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStaticPlugin
void __qt_destruct_QStaticPlugin(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStaticPlugin")
    reinterpret_cast<QStaticPlugin*>(ptr)->~QStaticPlugin();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStaticPlugin::metaData()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStaticPlugin_metaData_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QStaticPlugin *__qt_this = QtJambiAPI::objectFromNativeId<QStaticPlugin>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStaticPlugin::metaData()const", __qt_this)
        QJsonObject __qt_return_value = __qt_this->metaData();
        QJsonValue iid = __qt_return_value.value("IID");
        if(iid.isString()){
            if(jclass iface = CoreAPI::getInterfaceByIID(__jni_env, iid.toString().toUtf8())){
                __qt_return_value.take("IID");
                __qt_return_value.insert("interface", QJsonValue::fromVariant(QVariant::fromValue<JObjectWrapper>(JObjectWrapper(__jni_env, iface))));
            }
        }
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStaticPlugin_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStaticPlugin *__qt_this = QtJambiAPI::objectFromNativeId<QStaticPlugin>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStaticPlugin(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStaticPlugin>("QStaticPlugin", "io/qt/core/QStaticPlugin");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStaticPlugin, {
        ConstructorInfo(&__qt_construct_QStaticPlugin, nullptr)
       ,ConstructorInfo(&__qt_construct_QStaticPlugin_cref_QStaticPlugin, "Lio/qt/core/QStaticPlugin;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStaticPlugin);
    registerMetaType<QStaticPlugin>("QStaticPlugin");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
